@@ -4,23 +4,20 @@ from typing import Union
 
 from py4j.java_gateway import JavaGateway
 
-from .config import g_config
 from .common.types.conversion.type_converters import py_list_to_j_array
+from .common.utils.packages import is_flink_1_9
+from .config import g_config
 from .py4j_util import get_java_gateway, get_java_class, set_java_gateway, LocalJvmBridge
-from .common.utils.packages import get_alink_lib_path, get_pyflink_path, has_pyflink
 
-if has_pyflink():
-    __all__ = ["useLocalEnv", "useRemoteEnv", "useCustomEnv", "getMLEnv", "resetEnv"]
-else:
-    __all__ = ["useLocalEnv", "useRemoteEnv", "getMLEnv", "resetEnv"]
+__all__ = ["useLocalEnv", "useRemoteEnv", "useCustomEnv", "getMLEnv", "resetEnv"]
 
 MLEnv = collections.namedtuple('MLEnv', 'benv btenv senv stenv')
 _mlenv: MLEnv = None
 _in_custom_env: bool = False
 
 
-def _add_default_configurations(configuration, parallelism: int):
-    if has_pyflink():
+def add_default_configurations(configuration, parallelism: int):
+    if not is_flink_1_9():
         configuration.setString("taskmanager.memory.managed.size", str(64 * parallelism) + "m")
         configuration.setString("taskmanager.memory.network.min", str(64 * parallelism) + "m")
     else:
@@ -29,9 +26,9 @@ def _add_default_configurations(configuration, parallelism: int):
         configuration.setDouble("taskmanager.memory.fraction", 0.3)
 
 
-def _make_j_configuration(config, parallelism: int):
+def make_j_configuration(config, parallelism: int):
     configuration = get_java_gateway().jvm.org.apache.flink.configuration.Configuration()
-    _add_default_configurations(configuration, parallelism)
+    add_default_configurations(configuration, parallelism)
 
     if config is None:
         return configuration
@@ -52,6 +49,15 @@ def _make_j_configuration(config, parallelism: int):
     return configuration
 
 
+def setup_alink_plugins_path():
+    alink_plugins_path = g_config['alink_plugins_dir']
+    os.makedirs(alink_plugins_path, exist_ok=True)
+    from .config import AlinkGlobalConfiguration
+    prev_plugin_dir = AlinkGlobalConfiguration.getPluginDir()
+    if prev_plugin_dir == 'plugins':    # not set before
+        AlinkGlobalConfiguration.setPluginDir(alink_plugins_path)
+
+
 def setup_py_flink_env(gateway: JavaGateway, j_benv: object, j_senv: object) -> MLEnv:
     from pyflink.dataset import ExecutionEnvironment
     from pyflink.datastream import StreamExecutionEnvironment
@@ -89,27 +95,22 @@ def setup_java_ml_env(gateway, benv, btenv, senv, stenv):
         senv._j_stream_execution_environment,
         stenv._j_tenv
     )
+    gateway.jvm.com.alibaba.alink.common.MLEnvironmentFactory.remove(0)
     gateway.jvm.com.alibaba.alink.common.MLEnvironmentFactory.setDefault(j_mlenv)
     return j_mlenv
 
 
 def setup_py_ml_env(gateway: JavaGateway, j_benv: object, j_senv: object):
-    if has_pyflink():
-        benv, btenv, senv, stenv = setup_py_flink_env(gateway, j_benv, j_senv)
-        setup_java_ml_env(gateway, benv, btenv, senv, stenv)
-        mlenv = MLEnv(benv, btenv, senv, stenv)
-    else:
-        j_btenv = get_java_class("org.apache.flink.table.api.java.BatchTableEnvironment").create(j_benv)
-        j_stenv = get_java_class("org.apache.flink.table.api.java.StreamTableEnvironment").create(j_senv)
-        j_mlenv = gateway.jvm.com.alibaba.alink.common.MLEnvironment(j_benv, j_btenv, j_senv, j_stenv)
-        gateway.jvm.com.alibaba.alink.common.MLEnvironmentFactory.setDefault(j_mlenv)
-        mlenv = MLEnv(j_benv, j_btenv, j_senv, j_stenv)
+    benv, btenv, senv, stenv = setup_py_flink_env(gateway, j_benv, j_senv)
+    setup_java_ml_env(gateway, benv, btenv, senv, stenv)
+    mlenv = MLEnv(benv, btenv, senv, stenv)
     return mlenv
 
 
 def useLocalEnv(parallelism: int, flinkHome: str = None, config: object = None) -> MLEnv:
     """
     Start a local Flink mini-cluster as the execution environment
+    :rtype: object
     :param parallelism: parallelism to run tasks
     :param flinkHome: Flink home directory
     :param config: additional config for Flink local cluster
@@ -119,13 +120,15 @@ def useLocalEnv(parallelism: int, flinkHome: str = None, config: object = None)
         print("Warning: useLocalEnv will do nothing, since useCustomEnv is used to initialize MLEnv.")
         return
     resetEnv()
-    g_config["alink_deps_dir"] = get_alink_lib_path()
-    g_config["flink_home"] = get_pyflink_path() if flinkHome is None else flinkHome
+    if flinkHome is not None:
+        g_config["flink_home"] = flinkHome
     if config is not None and "debug_mode" in config:
         g_config["debug_mode"] = config["debug_mode"]
-    j_configuration = _make_j_configuration(config, parallelism)
+    j_configuration = make_j_configuration(config, parallelism)
     gateway = get_java_gateway()
 
+    setup_alink_plugins_path()
+
     j_benv = gateway.jvm.org.apache.flink.api.java.ExecutionEnvironment.createLocalEnvironment(j_configuration)
     j_configuration.setString("classloader.parent-first-patterns.additional", "org.apache.flink.statefun;org.apache.kafka;com.google.protobuf")
     j_senv = gateway.jvm.org.apache.flink.streaming.api.environment.StreamExecutionEnvironment.createLocalEnvironment(
@@ -164,14 +167,16 @@ def useRemoteEnv(host: str, port: Union[int, str], parallelism: int, flinkHome:
         port = int(port)
 
     resetEnv()
-    alink_lib_path = get_alink_lib_path()
-    g_config["alink_deps_dir"] = alink_lib_path
     g_config["collect_storage_type"] = "memory"
     g_config["local_ip"] = localIp
-    g_config["flink_home"] = get_pyflink_path() if flinkHome is None else flinkHome
-    j_configuration = _make_j_configuration(config, parallelism)
+    if flinkHome is not None:
+        g_config["flink_home"] = flinkHome
+    j_configuration = make_j_configuration(config, parallelism)
     gateway = get_java_gateway()
 
+    setup_alink_plugins_path()
+
+    alink_lib_path = g_config['alink_deps_dir']
     if shipAlinkAlgoJar:
         jar_files = [os.path.join(alink_lib_path, f) for f in os.listdir(alink_lib_path) if f.endswith(".jar")]
     else:
@@ -200,8 +205,8 @@ def usePyFlinkEnv(parallelism: int = None, flinkHome: str = None) -> MLEnv:
         return
 
     resetEnv()
-    g_config["alink_deps_dir"] = get_alink_lib_path()
-    g_config["flink_home"] = get_pyflink_path() if flinkHome is None else flinkHome
+    if flinkHome is not None:
+        g_config["flink_home"] = flinkHome
 
     if g_config["flink_home"] is None:
         # Running using flink run ***.py
@@ -265,11 +270,7 @@ def useCustomEnv(gateway, benv, btenv, senv, stenv):
 def getMLEnv() -> MLEnv:
     global _mlenv
     if _mlenv is None:
-        if has_pyflink():
-            _mlenv = usePyFlinkEnv()
-        else:
-            raise Exception(
-                "Call useLocalEnv/useRemoteEnv to initialize MLEnv first, or update to a newer version of PyAlink which depends on PyFlink-1.10 to use PyFlink env.")
+        _mlenv = usePyFlinkEnv()
     return _mlenv
 
 
