@@ -2,7 +2,7 @@ import base64
 import json
 
 from ..common.utils.encoding import ensure_unicode
-from ..common.utils.packages import has_pyflink
+from ..common.utils.packages import is_flink_1_9
 from ..py4j_util import get_java_class
 
 
@@ -17,9 +17,6 @@ def _to_cloudpickle_base64(v):
 
 
 def _to_flink_type_string(data_type):
-    if not has_pyflink():
-        return data_type.name
-
     from pyflink.table.types import _to_java_type
     FlinkTypeConverter = get_java_class("com.alibaba.alink.operator.common.io.types.FlinkTypeConverter")
     type_string = FlinkTypeConverter.getTypeString(_to_java_type(data_type))
@@ -36,24 +33,16 @@ def _to_flink_type_string(data_type):
 def _java_register_function(name, j_func, env_type):
     if env_type not in ('batch', 'stream'):
         raise ValueError("env_type should be 'batch' or 'stream'")
-    if has_pyflink():
-        if env_type == "batch":
-            from pyalink.alink import env
-            env._mlenv.btenv._j_tenv.registerFunction(name, j_func)
-        elif env_type == "stream":
-            from pyalink.alink import env
-            env._mlenv.stenv._j_tenv.registerFunction(name, j_func)
-    else:
-        if env_type == "batch":
-            from pyalink.alink import env
-            env._mlenv.btenv.registerFunction(name, j_func)
-        elif env_type == "stream":
-            from pyalink.alink import env
-            env._mlenv.stenv.registerFunction(name, j_func)
+    if env_type == "batch":
+        from pyalink.alink import env
+        env._mlenv.btenv._j_tenv.registerFunction(name, j_func)
+    elif env_type == "stream":
+        from pyalink.alink import env
+        env._mlenv.stenv._j_tenv.registerFunction(name, j_func)
 
 
 def register_pyflink_function(name, func, env_type):
-    if has_pyflink():
+    if not is_flink_1_9():
         from pyflink.table.udf import UserDefinedFunctionWrapper
     else:
         from .udf import UserDefinedFunctionWrapper
@@ -118,7 +107,7 @@ def do_set_op_udf(op, func):
         op.setClassObjectType("CLOUDPICKLE_BASE64")
         return op
 
-    if has_pyflink():
+    if not is_flink_1_9():
         from pyflink.table.udf import UserDefinedFunctionWrapper
     else:
         from .udf import UserDefinedFunctionWrapper
